/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2023                                                     **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef POPSERVER_REQUEST_H
#define POPSERVER_REQUEST_H

#include <vector>
#include <utility>
#include <stdint.h>
#include "json.hpp"
using json = nlohmann::json;
namespace popserver_request
{
/**
 * @brief The POPServerPlugin class  is working on server side plugins. It is called by the
 * corresponding client side plugin POP Advisor .
 */
struct POPServerRequest
{
    int32_t                 pop_analysis;
    std::vector< uint64_t > cnodes;
    std::vector< uint64_t > state;
};


void
to_json( json& j, const POPServerRequest& p )
{
    j = json { { "pop_analysis", p.pop_analysis }, { "cnodes", p.cnodes }, { "state", p.state } };
}

void
from_json( const json& j, POPServerRequest& p )
{
    j.at( "pop_analysis" ).get_to( p.pop_analysis );
    j.at( "cnodes" ).get_to( p.cnodes );
    j.at( "state" ).get_to( p.state );
}


struct POPServerAnswer
{
    std::vector< std::string > pop_metric_names;
    std::vector< std::string > io_metric_names;
    std::vector< std::string > additional_metric_names;
    std::vector< std::string > control_metric_names;
    std::vector< double >      pop_values;
    std::vector< double >      io_values;
    std::vector< double >      additional_values;
    std::vector< double >      control_values;

    std::string                pop_analysis_help;
    std::vector<std::string>   pop_metrics_helps;
    std::vector<std::string>   io_metrics_helps;
    std::vector<std::string>   additional_metrics_helps;
    std::vector<std::string>   control_metrics_helps;
};

void
to_json( json& j, const POPServerAnswer& p )
{
    j = json
    {
        { "pop_metric_names", p.pop_metric_names },
        { "io_metric_names", p.io_metric_names },
        { "additional_metric_names", p.additional_metric_names },
        { "control_metric_names", p.control_metric_names },
        { "pop_values", p.pop_values },
        { "io_values", p.io_values },
        { "additional_values", p.additional_values },
        { "control_values", p.control_values },
        { "pop_analysis_help", p.pop_analysis_help },
        { "pop_metrics_helps", p.pop_metrics_helps },
        { "io_metrics_helps", p.io_metrics_helps },
        { "additional_metrics_helps", p.additional_metrics_helps },
        { "control_metrics_helps", p.control_metrics_helps }
    };
}

void
from_json( const json& j, POPServerAnswer& p )
{
    j.at( "pop_metric_names" ).get_to( p.pop_metric_names );
    j.at( "io_metric_names" ).get_to( p.io_metric_names );
    j.at( "additional_metric_names" ).get_to( p.additional_metric_names );
    j.at( "control_metric_names" ).get_to( p.control_metric_names );
    j.at( "pop_values" ).get_to( p.pop_values );
    j.at( "io_values" ).get_to( p.io_values );
    j.at( "additional_values" ).get_to( p.additional_values );
    j.at( "control_values" ).get_to( p.control_values );
    j.at( "pop_analysis_help" ).get_to( p.pop_analysis_help );
    j.at( "pop_metrics_helps" ).get_to( p.pop_metrics_helps );
    j.at( "io_metrics_helps" ).get_to( p.io_metrics_helps );
    j.at( "additional_metrics_helps" ).get_to( p.additional_metrics_helps );
    j.at( "control_metrics_helps" ).get_to( p.control_metrics_helps );
}
};

#endif
